@@ -4,25 +4,24 @@ import (
 	"bytes"
 	"context"
 	"fmt"
+	"io/ioutil"
 	"net"
 	"net/http"
 	"strconv"
 	"time"
 
 	"github.com/onsi/ginkgo"
-	o "github.com/onsi/gomega"
-
-	v1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/util/wait"
-	"k8s.io/client-go/kubernetes/scheme"
-	"k8s.io/client-go/rest"
-	"k8s.io/client-go/tools/events"
-	"k8s.io/kubernetes/test/e2e/framework"
-	"k8s.io/kubernetes/test/e2e/framework/service"
-	"k8s.io/kubernetes/test/e2e/upgrades"
 
 	"github.com/openshift/origin/pkg/monitor"
 	"github.com/openshift/origin/test/extended/util/disruption"
+	v1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/util/wait"
+	"k8s.io/client-go/kubernetes/scheme"
+	"k8s.io/client-go/tools/events"
+	"k8s.io/kubernetes/test/e2e/framework"
+	e2enetwork "k8s.io/kubernetes/test/e2e/framework/network"
+	"k8s.io/kubernetes/test/e2e/framework/service"
+	"k8s.io/kubernetes/test/e2e/upgrades"
 )
 
 // UpgradeTest tests that a service is available before, during, and
@@ -42,13 +41,15 @@ func shouldTestPDBs() bool { return true }
 // Setup creates a service with a load balancer and makes sure it's reachable.
 func (t *UpgradeTest) Setup(f *framework.Framework) {
 	serviceName := "service-test"
-	jig := service.NewTestJig(f.ClientSet, serviceName)
+	jig := service.NewTestJig(f.ClientSet, f.Namespace.Name, serviceName)
 
 	ns := f.Namespace
+	cs := f.ClientSet
 
 	ginkgo.By("creating a TCP service " + serviceName + " with type=LoadBalancer in namespace " + ns.Name)
-	tcpService := jig.CreateTCPServiceOrFail(ns.Name, func(s *v1.Service) {
+	tcpService, err := jig.CreateTCPService(func(s *v1.Service) {
 		s.Spec.Type = v1.ServiceTypeLoadBalancer
+		s.Spec.ExternalTrafficPolicy = v1.ServiceExternalTrafficPolicyTypeLocal
 		if s.Annotations == nil {
 			s.Annotations = make(map[string]string)
 		}
@@ -62,15 +63,16 @@ func (t *UpgradeTest) Setup(f *framework.Framework) {
 		// - GCP has a non-configurable interval of 32s (3 failed health checks with 8s interval in 1.17)
 		//   - thus pods need to stay up for > 32s, so pod shutdown period will will be 45s
 	})
-	tcpService = jig.WaitForLoadBalancerOrFail(ns.Name, tcpService.Name, service.LoadBalancerLagTimeoutAWS)
-	jig.SanityCheckService(tcpService, v1.ServiceTypeLoadBalancer)
+	framework.ExpectNoError(err)
+	tcpService, err = jig.WaitForLoadBalancer(service.GetServiceLoadBalancerCreationTimeout(cs))
+	framework.ExpectNoError(err)
 
 	// Get info to hit it with
 	tcpIngressIP := service.GetIngressPoint(&tcpService.Status.LoadBalancer.Ingress[0])
 	svcPort := int(tcpService.Spec.Ports[0].Port)
 
 	ginkgo.By("creating RC to be part of service " + serviceName)
-	rc := jig.RunOrFail(ns.Name, func(rc *v1.ReplicationController) {
+	rc, err := jig.Run(func(rc *v1.ReplicationController) {
 		// ensure the pod waits long enough for most LBs to take it out of rotation, which has to be
 		// longer than the LB failed health check interval
 		rc.Spec.Template.Spec.Containers[0].Lifecycle = &v1.Lifecycle{
@@ -84,10 +86,12 @@ func (t *UpgradeTest) Setup(f *framework.Framework) {
 
 		jig.AddRCAntiAffinity(rc)
 	})
+	framework.ExpectNoError(err)
 
 	if shouldTestPDBs() {
 		ginkgo.By("creating a PodDisruptionBudget to cover the ReplicationController")
-		jig.CreatePDBOrFail(ns.Name, rc)
+		_, err = jig.CreatePDB(rc)
+		framework.ExpectNoError(err)
 	}
 
 	// Hit it once before considering ourselves ready
@@ -103,7 +107,7 @@ func (t *UpgradeTest) Setup(f *framework.Framework) {
 // Test runs a connectivity check to the service.
 func (t *UpgradeTest) Test(f *framework.Framework, done <-chan struct{}, upgrade upgrades.UpgradeType) {
 	client, err := framework.LoadClientset()
-	o.Expect(err).NotTo(o.HaveOccurred())
+	framework.ExpectNoError(err)
 
 	stopCh := make(chan struct{})
 	defer close(stopCh)
@@ -116,7 +120,7 @@ func (t *UpgradeTest) Test(f *framework.Framework, done <-chan struct{}, upgrade
 	ctx, cancel := context.WithCancel(context.Background())
 	m := monitor.NewMonitorWithInterval(1 * time.Second)
 	err = startEndpointMonitoring(ctx, m, t.tcpService, r)
-	o.Expect(err).NotTo(o.HaveOccurred(), "unable to monitor API")
+	framework.ExpectNoError(err, "unable to monitor API")
 
 	start := time.Now()
 	m.StartSampling(ctx)
@@ -147,10 +151,9 @@ func (t *UpgradeTest) Teardown(f *framework.Framework) {
 func startEndpointMonitoring(ctx context.Context, m *monitor.Monitor, svc *v1.Service, r events.EventRecorder) error {
 	tcpIngressIP := service.GetIngressPoint(&svc.Status.LoadBalancer.Ingress[0])
 	svcPort := int(svc.Spec.Ports[0].Port)
-
+	url := fmt.Sprintf("http://%s/echo?msg=Hello", net.JoinHostPort(tcpIngressIP, strconv.Itoa(svcPort)))
 	// this client reuses connections and detects abrupt breaks
-	continuousClient, err := rest.UnversionedRESTClientFor(&rest.Config{
-		Host:    fmt.Sprintf("http://%s", net.JoinHostPort(tcpIngressIP, strconv.Itoa(svcPort))),
+	continuousClient := &http.Client{
 		Timeout: 10 * time.Second,
 		Transport: &http.Transport{
 			Dial: (&net.Dialer{
@@ -158,18 +161,17 @@ func startEndpointMonitoring(ctx context.Context, m *monitor.Monitor, svc *v1.Se
 			}).Dial,
 			TLSHandshakeTimeout: 15 * time.Second,
 		},
-		ContentConfig: rest.ContentConfig{
-			NegotiatedSerializer: scheme.Codecs,
-		},
-	})
-	if err != nil {
-		return err
 	}
+
 	m.AddSampler(
 		monitor.StartSampling(ctx, m, time.Second, func(previous bool) (condition *monitor.Condition, next bool) {
-			data, err := continuousClient.Get().AbsPath("echo").Param("msg", "Hello").DoRaw()
-			if err == nil && !bytes.Contains(data, []byte("Hello")) {
-				err = fmt.Errorf("service returned success but did not contain the correct body contents: %q", string(data))
+			resp, err := continuousClient.Get(url)
+			if err == nil {
+				defer resp.Body.Close()
+				body, err := ioutil.ReadAll(resp.Body)
+				if err == nil && !bytes.Contains(body, []byte("Hello")) {
+					err = fmt.Errorf("service returned success but did not contain the correct body contents: %q", string(body))
+				}
 			}
 			switch {
 			case err == nil && !previous:
@@ -198,8 +200,7 @@ func startEndpointMonitoring(ctx context.Context, m *monitor.Monitor, svc *v1.Se
 	)
 
 	// this client creates fresh connections and detects failure to establish connections
-	client, err := rest.UnversionedRESTClientFor(&rest.Config{
-		Host:    fmt.Sprintf("http://%s", net.JoinHostPort(tcpIngressIP, strconv.Itoa(svcPort))),
+	client := &http.Client{
 		Timeout: 10 * time.Second,
 		Transport: &http.Transport{
 			Dial: (&net.Dialer{
@@ -210,18 +211,16 @@ func startEndpointMonitoring(ctx context.Context, m *monitor.Monitor, svc *v1.Se
 			IdleConnTimeout:     15 * time.Second,
 			DisableKeepAlives:   true,
 		},
-		ContentConfig: rest.ContentConfig{
-			NegotiatedSerializer: scheme.Codecs,
-		},
-	})
-	if err != nil {
-		return err
 	}
 	m.AddSampler(
 		monitor.StartSampling(ctx, m, time.Second, func(previous bool) (condition *monitor.Condition, next bool) {
-			data, err := client.Get().AbsPath("echo").Param("msg", "Hello").DoRaw()
-			if err == nil && !bytes.Contains(data, []byte("Hello")) {
-				err = fmt.Errorf("service returned success but did not contain the correct body contents: %q", string(data))
+			resp, err := client.Get(url)
+			if err == nil {
+				defer resp.Body.Close()
+				body, err := ioutil.ReadAll(resp.Body)
+				if err == nil && !bytes.Contains(body, []byte("Hello")) {
+					err = fmt.Errorf("service returned success but did not contain the correct body contents: %q", string(body))
+				}
 			}
 			switch {
 			case err == nil && !previous:
@@ -260,12 +259,12 @@ func locateService(svc *v1.Service) string {
 func TestReachableHTTPWithMinSuccessCount(host string, port int, successCount int, timeout time.Duration) {
 	consecutiveSuccessCnt := 0
 	err := wait.PollImmediate(framework.Poll, timeout, func() (bool, error) {
-		result := framework.PokeHTTP(host, port, "/echo?msg=hello",
-			&framework.HTTPPokeParams{
+		result := e2enetwork.PokeHTTP(host, port, "/echo?msg=hello",
+			&e2enetwork.HTTPPokeParams{
 				BodyContains:   "hello",
 				RetriableCodes: []int{},
 			})
-		if result.Status == framework.HTTPSuccess {
+		if result.Status == e2enetwork.HTTPSuccess {
 			consecutiveSuccessCnt++
 			return consecutiveSuccessCnt >= successCount, nil
 		}
