@@ -1,5 +1,7 @@
 package extended
 
+//go:generate go run ./util/annotate -- ./util/annotate/generated/zz_generated.annotations.go
+
 import (
 	_ "k8s.io/kubernetes/test/e2e"
 
@@ -12,18 +14,12 @@ import (
 	_ "k8s.io/kubernetes/test/e2e/instrumentation"
 	_ "k8s.io/kubernetes/test/e2e/kubectl"
 
-	// _ "k8s.io/kubernetes/test/e2e/lifecycle"
-	// _ "k8s.io/kubernetes/test/e2e/lifecycle/bootstrap"
-	// _ "k8s.io/kubernetes/test/e2e/multicluster"
 	_ "k8s.io/kubernetes/test/e2e/network"
 	_ "k8s.io/kubernetes/test/e2e/node"
-	_ "k8s.io/kubernetes/test/e2e/scalability"
 	_ "k8s.io/kubernetes/test/e2e/scheduling"
 	_ "k8s.io/kubernetes/test/e2e/servicecatalog"
 	_ "k8s.io/kubernetes/test/e2e/storage"
 
-	// _ "k8s.io/kubernetes/test/e2e/ui"
-
 	_ "github.com/openshift/origin/test/extended/apiserver"
 	_ "github.com/openshift/origin/test/extended/authentication"
 	_ "github.com/openshift/origin/test/extended/authorization"
@@ -48,6 +44,7 @@ import (
 	_ "github.com/openshift/origin/test/extended/jobs"
 	_ "github.com/openshift/origin/test/extended/localquota"
 	_ "github.com/openshift/origin/test/extended/machines"
+	_ "github.com/openshift/origin/test/extended/marketplace"
 	_ "github.com/openshift/origin/test/extended/networking"
 	_ "github.com/openshift/origin/test/extended/oauth"
 	_ "github.com/openshift/origin/test/extended/operators"
@@ -57,5 +54,6 @@ import (
 	_ "github.com/openshift/origin/test/extended/router"
 	_ "github.com/openshift/origin/test/extended/security"
 	_ "github.com/openshift/origin/test/extended/templates"
+	_ "github.com/openshift/origin/test/extended/topology_manager"
 	_ "github.com/openshift/origin/test/extended/user"
 )
