@@ -1,6 +1,7 @@
 package oauth
 
 import (
+	"context"
 	"crypto/rand"
 	"crypto/rsa"
 	"crypto/tls"
@@ -26,6 +27,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 	corev1client "k8s.io/client-go/kubernetes/typed/core/v1"
 	e2e "k8s.io/kubernetes/test/e2e/framework"
+	e2eskipper "k8s.io/kubernetes/test/e2e/framework/skipper"
 
 	configv1 "github.com/openshift/api/config/v1"
 	osinv1 "github.com/openshift/api/osin/v1"
@@ -57,20 +59,19 @@ type certAuthTest struct {
 	expectedError string
 }
 
-var _ = g.Describe("[Serial] [Feature:OAuthServer] [RequestHeaders] [IdP]", func() {
-	var oc = exutil.NewCLI("request-headers", exutil.KubeConfigPath())
+var _ = g.Describe("[Serial] [sig-auth][Feature:OAuthServer] [RequestHeaders] [IdP]", func() {
+	var oc = exutil.NewCLI("request-headers")
 
 	g.It("test RequestHeaders IdP", func() {
-
 		if e2e.TestContext.Provider == ibmcloud.ProviderName {
-			e2e.Skipf("IBM ROKS clusters do not allow customization of the Identity Providers for the cluster.")
+			e2eskipper.Skipf("IBM ROKS clusters do not allow customization of the Identity Providers for the cluster.")
 		}
 
 		caCert, caKey := createClientCA(oc.AdminKubeClient().CoreV1())
-		defer oc.AdminKubeClient().CoreV1().ConfigMaps("openshift-config").Delete(clientCAName, &metav1.DeleteOptions{})
+		defer oc.AdminKubeClient().CoreV1().ConfigMaps("openshift-config").Delete(context.Background(), clientCAName, metav1.DeleteOptions{})
 
 		changeTime := time.Now()
-		oauthClusterOrig, err := oc.AdminConfigClient().ConfigV1().OAuths().Get("cluster", metav1.GetOptions{})
+		oauthClusterOrig, err := oc.AdminConfigClient().ConfigV1().OAuths().Get(context.Background(), "cluster", metav1.GetOptions{})
 		o.Expect(err).NotTo(o.HaveOccurred())
 
 		oauthCluster := oauthClusterOrig.DeepCopy()
@@ -94,20 +95,20 @@ var _ = g.Describe("[Serial] [Feature:OAuthServer] [RequestHeaders] [IdP]", func
 				},
 			},
 		}
-		_, err = oc.AdminConfigClient().ConfigV1().OAuths().Update(oauthCluster)
+		_, err = oc.AdminConfigClient().ConfigV1().OAuths().Update(context.Background(), oauthCluster, metav1.UpdateOptions{})
 		o.Expect(err).NotTo(o.HaveOccurred())
 		// clean up after ourselves
 		defer func() {
 			userclient := oc.AdminUserClient().UserV1()
-			userclient.Identities().Delete(fmt.Sprintf("%s:%s", idpName, testUserName), &metav1.DeleteOptions{})
-			userclient.Users().Delete(testUserName, &metav1.DeleteOptions{})
+			userclient.Identities().Delete(context.Background(), fmt.Sprintf("%s:%s", idpName, testUserName), metav1.DeleteOptions{})
+			userclient.Users().Delete(context.Background(), testUserName, metav1.DeleteOptions{})
 
-			oauthCluster, err := oc.AdminConfigClient().ConfigV1().OAuths().Get("cluster", metav1.GetOptions{})
+			oauthCluster, err := oc.AdminConfigClient().ConfigV1().OAuths().Get(context.Background(), "cluster", metav1.GetOptions{})
 			if err != nil {
 				g.Fail(fmt.Sprintf("Failed to get oauth/cluster, unable to turn it into its original state: %v", err))
 			}
 			oauthCluster.Spec = oauthClusterOrig.Spec
-			_, err = oc.AdminConfigClient().ConfigV1().OAuths().Update(oauthCluster)
+			_, err = oc.AdminConfigClient().ConfigV1().OAuths().Update(context.Background(), oauthCluster, metav1.UpdateOptions{})
 			if err != nil {
 				g.Fail(fmt.Sprintf("Failed to update oauth/cluster, unable to turn it into its original state: %v", err))
 			}
@@ -184,7 +185,7 @@ var _ = g.Describe("[Serial] [Feature:OAuthServer] [RequestHeaders] [IdP]", func
 		caCerts, err := x509.SystemCertPool()
 		o.Expect(err).NotTo(o.HaveOccurred())
 
-		routerCA, err := oc.AdminKubeClient().CoreV1().ConfigMaps("openshift-config-managed").Get("router-ca", metav1.GetOptions{})
+		routerCA, err := oc.AdminKubeClient().CoreV1().ConfigMaps("openshift-config-managed").Get(context.Background(), "default-ingress-cert", metav1.GetOptions{})
 		o.Expect(err).NotTo(o.HaveOccurred())
 
 		for _, ca := range routerCA.Data {
@@ -304,14 +305,14 @@ func generateCA(cn string) (*x509.Certificate, *rsa.PrivateKey) {
 // returns CA cert and private key
 func createClientCA(client corev1client.CoreV1Interface) (*x509.Certificate, *rsa.PrivateKey) {
 	caCert, caKey := generateCA("Testing CA")
-	_, err := client.ConfigMaps("openshift-config").Create(&corev1.ConfigMap{
+	_, err := client.ConfigMaps("openshift-config").Create(context.Background(), &corev1.ConfigMap{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: clientCAName,
 		},
 		Data: map[string]string{
 			"ca.crt": string(pem.EncodeToMemory(&pem.Block{Type: "CERTIFICATE", Bytes: caCert.Raw})),
 		},
-	})
+	}, metav1.CreateOptions{})
 	o.Expect(err).NotTo(o.HaveOccurred())
 
 	return caCert, caKey
@@ -349,8 +350,9 @@ func generateCert(caCert *x509.Certificate, caKey *rsa.PrivateKey, cn string, ek
 func waitForNewOAuthConfig(oc *exutil.CLI, caCerts *x509.CertPool, oauthURL string, configChanged time.Time) {
 	// check that the pods running in openshift-authentication NS already reflect our changes
 	err := wait.PollImmediate(time.Second, 2*time.Minute, func() (bool, error) {
-		pods, err := oc.AdminKubeClient().CoreV1().Pods("openshift-authentication").List(metav1.ListOptions{})
+		pods, err := oc.AdminKubeClient().CoreV1().Pods("openshift-authentication").List(context.Background(), metav1.ListOptions{})
 		if err != nil {
+			e2e.Logf("Error listing openshift-authentication pods: %v", err)
 			return false, err
 		}
 
@@ -358,6 +360,8 @@ func waitForNewOAuthConfig(oc *exutil.CLI, caCerts *x509.CertPool, oauthURL stri
 		for _, p := range pods.Items {
 			tstamp := p.GetCreationTimestamp()
 			if !tstamp.After(configChanged) {
+				e2e.Logf("Pod %q not ready (creation timestamp: %s, config changed: %s)", p.Name, p.GetCreationTimestamp(), configChanged)
+				e2e.Logf("Pod %q status: %s", p.Name, spew.Sdump(p.Status))
 				podsReady = false
 			}
 			if podsReady {
@@ -368,8 +372,8 @@ func waitForNewOAuthConfig(oc *exutil.CLI, caCerts *x509.CertPool, oauthURL stri
 	})
 	o.Expect(err).NotTo(o.HaveOccurred())
 
-	err = wait.PollImmediate(time.Second, time.Minute, func() (bool, error) {
-		authn, err := oc.AdminConfigClient().ConfigV1().ClusterOperators().Get("authentication", metav1.GetOptions{})
+	err = wait.PollImmediate(time.Second, 5*time.Minute, func() (bool, error) {
+		authn, err := oc.AdminConfigClient().ConfigV1().ClusterOperators().Get(context.Background(), "authentication", metav1.GetOptions{})
 		if err != nil {
 			e2e.Logf("Error getting authentication operator: %v", err)
 			return false, err
